@@ -4,6 +4,7 @@
 #include "videocontroller.h"
 
 #include "config.h"
+#include "general_logging.h"
 #include "plasmatube.h"
 
 #ifdef HAS_DBUS
@@ -82,7 +83,7 @@ VideoController::VideoController(QObject *parent)
 void VideoController::play(const QString &videoId)
 {
     if (videoId.isEmpty()) {
-        qWarning() << "Not trying to play an empty video id.";
+        qCWarning(PLASMATUBE_GENERAL) << "Not trying to play an empty video id.";
         return;
     }
 
@@ -92,7 +93,7 @@ void VideoController::play(const QString &videoId)
 void VideoController::queueNext(const QString &videoId)
 {
     if (videoId.isEmpty()) {
-        qWarning() << "Not trying to queue an empty video id.";
+        qCWarning(PLASMATUBE_GENERAL) << "Not trying to queue an empty video id.";
         return;
     }
 
@@ -164,9 +165,9 @@ void VideoController::setCurrentPlayer(MpvObject *mpvObject)
         if (m_currentPlayer != nullptr) {
             Q_EMIT m_currentPlayer->command(QStringList() << QStringLiteral("stop"));
             oldPosition = m_currentPlayer->position();
-        }
 
-        m_currentPlayer->disconnect(this);
+            m_currentPlayer->disconnect(this);
+        }
 
         m_currentPlayer = mpvObject;
         Q_EMIT currentPlayerChanged();
