@@ -6,7 +6,7 @@
 #include "controllers/plasmatube.h"
 #include "controllers/subscriptioncontroller.h"
 #include "models/videolistmodel.h"
-#include "models/videomodel.h"
+#include "utils/linkparser.h"
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -31,17 +31,9 @@
 #include "controllers/windowcontroller.h"
 #include "plasmatube-version.h"
 
-std::optional<QString> parseVideoString(const QString &vid)
-{
-    const QRegularExpression exp(QStringLiteral(R"(https:\/\/[www.]*youtube.com\/watch\?v=(.*))"));
-    const auto match = exp.match(vid);
-    if (match.hasMatch()) {
-        return match.captured(1);
-    }
-
-    return std::nullopt;
-}
-
+#ifdef Q_OS_ANDROID
+Q_DECL_EXPORT
+#endif
 int main(int argc, char **argv)
 {
 #ifdef Q_OS_ANDROID
@@ -63,8 +55,13 @@ int main(int argc, char **argv)
                      QStringLiteral(PLASMATUBE_VERSION_STRING),
                      i18n("YouTube client"),
                      KAboutLicense::GPL_V3,
-                     i18n("© Linus Jahn"));
+                     i18n("© 2019-2024 Linus Jahn, 2019-2024 KDE Community"));
     about.addAuthor(i18n("Linus Jahn"), i18n("Creator"), QStringLiteral("lnj@kaidan.im"));
+    about.addAuthor(i18n("Joshua Goins"),
+                    i18n("Maintainer"),
+                    QStringLiteral("josh@redstrate.com"),
+                    QStringLiteral("https://redstrate.com/"),
+                    QUrl(QStringLiteral("https://redstrate.com/rss-image.png")));
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     about.setOrganizationDomain("kde.org");
     about.setBugAddress("https://bugs.kde.org/describecomponents.cgi?product=plasmatube");
@@ -91,7 +88,7 @@ int main(int argc, char **argv)
                 args.removeFirst();
 
                 if (arguments.length() >= 1) {
-                    if (const auto videoUrl = parseVideoString(args[0])) {
+                    if (const auto videoUrl = LinkParser::parseVideoString(args[0])) {
                         PlasmaTube::instance().openVideo(*videoUrl);
                     }
                 }
@@ -104,28 +101,23 @@ int main(int argc, char **argv)
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
-    PlasmaTubeSettings settings(KSharedConfig::openConfig(QStringLiteral("plasmatuberc"), KConfig::SimpleConfig, QStandardPaths::AppConfigLocation));
-    qmlRegisterSingletonInstance<PlasmaTubeSettings>("org.kde.plasmatube.private", 1, 0, "Settings", &settings);
-    QObject::connect(&app, &QCoreApplication::aboutToQuit, &settings, &PlasmaTubeSettings::save);
-
-    qmlRegisterType<MpvObject>("org.kde.plasmatube.private", 1, 0, "MpvObject");
+    auto &plasmatubeInstance = PlasmaTube::instance();
+    qmlRegisterSingletonInstance<PlasmaTubeSettings>("org.kde.plasmatube.private", 1, 0, "Settings", plasmatubeInstance.settings());
+    QObject::connect(&app, &QCoreApplication::aboutToQuit, plasmatubeInstance.settings(), &PlasmaTubeSettings::save);
 
     QCommandLineParser parser;
-    parser.setApplicationDescription(i18n("YouTube client"));
-
     parser.addPositionalArgument(QStringLiteral("video-url"), QStringLiteral("YouTube video URL to play"));
 
     about.setupCommandLine(&parser);
     parser.process(app);
-    about.processCommandLine(&parser);
 
     engine.loadFromModule(QStringLiteral("org.kde.plasmatube"), QStringLiteral("Main"));
 
     if (engine.rootObjects().isEmpty())
         return -1;
 
-    if (QCoreApplication::arguments().length() > 1) {
-        if (const auto videoUrl = parseVideoString(app.arguments()[1])) {
+    if (parser.positionalArguments().length() >= 1) {
+        if (const auto videoUrl = LinkParser::parseVideoString(parser.positionalArguments().first())) {
             PlasmaTube::instance().openVideo(*videoUrl);
         }
     }
@@ -149,5 +141,5 @@ int main(int argc, char **argv)
     }
 #endif
 
-    return app.exec();
+    return QCoreApplication::exec();
 }
